@@ -23,61 +23,59 @@ import locale
 import os
 import pty
 import shutil
-import tempfile
-import unittest
 import sys
+try:
+    assert sys.version_info >= (2, 7)
+    import unittest
+except AssertionError:
+    import unittest2 as unittest
 
 from yamllint import cli
 
+from tests.common import build_temp_workspace
 
+
+@unittest.skipIf(sys.version_info < (2, 7), 'Python 2.6 not supported')
 class CommandLineTestCase(unittest.TestCase):
-    def setUp(self):
-        self.wd = tempfile.mkdtemp(prefix='yamllint-tests-')
+    @classmethod
+    def setUpClass(cls):
+        super(CommandLineTestCase, cls).setUpClass()
 
-        # .yaml file at root
-        with open(os.path.join(self.wd, 'a.yaml'), 'w') as f:
-            f.write('---\n'
-                    '- 1   \n'
-                    '- 2')
+        cls.wd = build_temp_workspace({
+            # .yaml file at root
+            'a.yaml': '---\n'
+                      '- 1   \n'
+                      '- 2',
+            # file with only one warning
+            'warn.yaml': 'key: value\n',
+            # .yml file at root
+            'empty.yml': '',
+            # file in dir
+            'sub/ok.yaml': '---\n'
+                           'key: value\n',
+            # file in very nested dir
+            's/s/s/s/s/s/s/s/s/s/s/s/s/s/s/file.yaml': '---\n'
+                                                       'key: value\n'
+                                                       'key: other value\n',
+            # empty dir
+            'empty-dir': [],
+            # non-YAML file
+            'no-yaml.json': '---\n'
+                            'key: value\n',
+            # non-ASCII chars
+            'non-ascii/utf-8': (
+                u'---\n'
+                u'- hétérogénéité\n'
+                u'# 19.99 €\n'
+                u'- お早う御座います。\n'
+                u'# الأَبْجَدِيَّة العَرَبِيَّة\n').encode('utf-8'),
+        })
 
-        # .yml file at root
-        open(os.path.join(self.wd, 'empty.yml'), 'w').close()
+    @classmethod
+    def tearDownClass(cls):
+        super(CommandLineTestCase, cls).tearDownClass()
 
-        # file in dir
-        os.mkdir(os.path.join(self.wd, 'sub'))
-        with open(os.path.join(self.wd, 'sub', 'ok.yaml'), 'w') as f:
-            f.write('---\n'
-                    'key: value\n')
-
-        # file in very nested dir
-        dir = self.wd
-        for i in range(15):
-            dir = os.path.join(dir, 's')
-            os.mkdir(dir)
-        with open(os.path.join(dir, 'file.yaml'), 'w') as f:
-            f.write('---\n'
-                    'key: value\n'
-                    'key: other value\n')
-
-        # empty dir
-        os.mkdir(os.path.join(self.wd, 'empty-dir'))
-
-        # non-YAML file
-        with open(os.path.join(self.wd, 'no-yaml.json'), 'w') as f:
-            f.write('---\n'
-                    'key: value\n')
-
-        # non-ASCII chars
-        os.mkdir(os.path.join(self.wd, 'non-ascii'))
-        with open(os.path.join(self.wd, 'non-ascii', 'utf-8'), 'wb') as f:
-            f.write((u'---\n'
-                     u'- hétérogénéité\n'
-                     u'# 19.99 €\n'
-                     u'- お早う御座います。\n'
-                     u'# الأَبْجَدِيَّة العَرَبِيَّة\n').encode('utf-8'))
-
-    def tearDown(self):
-        shutil.rmtree(self.wd)
+        shutil.rmtree(cls.wd)
 
     def test_find_files_recursively(self):
         self.assertEqual(
@@ -85,7 +83,8 @@ class CommandLineTestCase(unittest.TestCase):
             [os.path.join(self.wd, 'a.yaml'),
              os.path.join(self.wd, 'empty.yml'),
              os.path.join(self.wd, 's/s/s/s/s/s/s/s/s/s/s/s/s/s/s/file.yaml'),
-             os.path.join(self.wd, 'sub/ok.yaml')],
+             os.path.join(self.wd, 'sub/ok.yaml'),
+             os.path.join(self.wd, 'warn.yaml')],
         )
 
         items = [os.path.join(self.wd, 'sub/ok.yaml'),
@@ -140,8 +139,11 @@ class CommandLineTestCase(unittest.TestCase):
 
         out, err = sys.stdout.getvalue(), sys.stderr.getvalue()
         self.assertEqual(out, '')
-        self.assertRegexpMatches(err, r'^Options --config-file and '
-                                      r'--config-data cannot be used')
+        self.assertRegexpMatches(
+            err.splitlines()[-1],
+            r'^yamllint: error: argument -d\/--config-data: '
+            r'not allowed with argument -c\/--config-file$'
+        )
 
     def test_run_with_bad_config(self):
         sys.stdout, sys.stderr = StringIO(), StringIO()
@@ -247,6 +249,24 @@ class CommandLineTestCase(unittest.TestCase):
             '(new-line-at-end-of-file)\n') % (file, file))
         self.assertEqual(err, '')
 
+    def test_run_one_warning(self):
+        file = os.path.join(self.wd, 'warn.yaml')
+
+        sys.stdout, sys.stderr = StringIO(), StringIO()
+        with self.assertRaises(SystemExit) as ctx:
+            cli.run(('-f', 'parsable', file))
+
+        self.assertEqual(ctx.exception.code, 0)
+
+    def test_run_warning_in_strict_mode(self):
+        file = os.path.join(self.wd, 'warn.yaml')
+
+        sys.stdout, sys.stderr = StringIO(), StringIO()
+        with self.assertRaises(SystemExit) as ctx:
+            cli.run(('-f', 'parsable', '--strict', file))
+
+        self.assertEqual(ctx.exception.code, 2)
+
     def test_run_one_ok_file(self):
         file = os.path.join(self.wd, 'sub', 'ok.yaml')
 
@@ -279,7 +299,10 @@ class CommandLineTestCase(unittest.TestCase):
         # Make sure the default localization conditions on this "system"
         # support UTF-8 encoding.
         loc = locale.getlocale()
-        locale.setlocale(locale.LC_ALL, 'C.UTF-8')
+        try:
+            locale.setlocale(locale.LC_ALL, 'C.UTF-8')
+        except locale.Error:
+            locale.setlocale(locale.LC_ALL, 'en_US.UTF-8')
 
         sys.stdout, sys.stderr = StringIO(), StringIO()
         with self.assertRaises(SystemExit) as ctx:
