@@ -24,9 +24,11 @@ from yamllint.rules import (
     document_end,
     document_start,
     empty_lines,
+    empty_values,
     hyphens,
     indentation,
     key_duplicates,
+    key_ordering,
     line_length,
     new_line_at_end_of_file,
     new_lines,
@@ -44,9 +46,11 @@ _RULES = {
     document_end.ID: document_end,
     document_start.ID: document_start,
     empty_lines.ID: empty_lines,
+    empty_values.ID: empty_values,
     hyphens.ID: hyphens,
     indentation.ID: indentation,
     key_duplicates.ID: key_duplicates,
+    key_ordering.ID: key_ordering,
     line_length.ID: line_length,
     new_line_at_end_of_file.ID: new_line_at_end_of_file,
     new_lines.ID: new_lines,
