@@ -25,12 +25,12 @@ Use this rule to control the indentation.
   same within the file.
 * ``indent-sequences`` defines whether block sequences should be indented or
   not (when in a mapping, this indentation is not mandatory -- some people
-  perceive the ``-`` as part of the indentation). Possible values: ``yes``,
-  ``no``, ``whatever`` and ``consistent``. ``consistent`` requires either all
-  block sequences to be indented, or none to be. ``whatever`` means either
+  perceive the ``-`` as part of the indentation). Possible values: ``true``,
+  ``false``, ``whatever`` and ``consistent``. ``consistent`` requires either
+  all block sequences to be indented, or none to be. ``whatever`` means either
   indenting or not indenting individual block sequences is OK.
 * ``check-multi-line-strings`` defines whether to lint indentation in
-  multi-line strings. Set to ``yes`` to enable, ``no`` to disable.
+  multi-line strings. Set to ``true`` to enable, ``false`` to disable.
 
 .. rubric:: Examples
 
@@ -99,7 +99,7 @@ Use this rule to control the indentation.
       Russian:
           dolls
 
-#. With ``indentation: {spaces: 2, indent-sequences: no}``
+#. With ``indentation: {spaces: 2, indent-sequences: false}``
 
    the following code snippet would **PASS**:
    ::
@@ -152,7 +152,7 @@ Use this rule to control the indentation.
       - spaghetti
       - sauce
 
-#. With ``indentation: {spaces: 4, check-multi-line-strings: yes}``
+#. With ``indentation: {spaces: 4, check-multi-line-strings: true}``
 
    the following code snippet would **PASS**:
    ::
@@ -399,6 +399,10 @@ def _check(conf, token, prev, next, nextnext, context):
             #   - item 1
             #   - item 2
             indent = next.start_mark.column
+        elif next.start_mark.column == token.start_mark.column:
+            #   -
+            #   key: value
+            indent = next.start_mark.column
         else:
             #   -
             #     item 1
@@ -469,7 +473,19 @@ def _check(conf, token, prev, next, nextnext, context):
                 if context['indent-sequences'] is False:
                     indent = context['stack'][-1].indent
                 elif context['indent-sequences'] is True:
-                    indent = detect_indent(context['stack'][-1].indent, next)
+                    if (context['spaces'] == 'consistent' and
+                            next.start_mark.column -
+                            context['stack'][-1].indent == 0):
+                        # In this case, the block sequence item is not indented
+                        # (while it should be), but we don't know yet the
+                        # indentation it should have (because `spaces` is
+                        # `consistent` and its value has not been computed yet
+                        # -- this is probably the beginning of the document).
+                        # So we choose an arbitrary value (2).
+                        indent = 2
+                    else:
+                        indent = detect_indent(context['stack'][-1].indent,
+                                               next)
                 else:  # 'whatever' or 'consistent'
                     if next.start_mark.column == context['stack'][-1].indent:
                         #   key:
